/****************************************************************************
** Meta object code from reading C++ file 'kcharselectdia.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kcharselect-26.04.3/kcharselectdia.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcharselectdia.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KCharSelectDiaE_t {};
} // unnamed namespace

template <> constexpr inline auto KCharSelectDia::qt_create_metaobjectdata<qt_meta_tag_ZN14KCharSelectDiaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCharSelectDia",
        "charChanged",
        "",
        "_chr",
        "fontSelected",
        "QFont",
        "_font",
        "add",
        "toClip",
        "toClipUTF8",
        "toClipHTML",
        "fromClip",
        "fromClipUTF8",
        "flipText",
        "setRtl",
        "rtl",
        "lineEditChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'charChanged'
        QtMocHelpers::SlotData<void(char32_t)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Char32, 3 },
        }}),
        // Slot 'fontSelected'
        QtMocHelpers::SlotData<void(const QFont &)>(4, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'add'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'add'
        QtMocHelpers::SlotData<void(char32_t)>(7, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Char32, 3 },
        }}),
        // Slot 'toClip'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toClipUTF8'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toClipHTML'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fromClip'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'fromClipUTF8'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'flipText'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setRtl'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'lineEditChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCharSelectDia, qt_meta_tag_ZN14KCharSelectDiaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCharSelectDia::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KCharSelectDiaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KCharSelectDiaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KCharSelectDiaE_t>.metaTypes,
    nullptr
} };

void KCharSelectDia::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCharSelectDia *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->charChanged((*reinterpret_cast<std::add_pointer_t<char32_t>>(_a[1]))); break;
        case 1: _t->fontSelected((*reinterpret_cast<std::add_pointer_t<QFont>>(_a[1]))); break;
        case 2: _t->add(); break;
        case 3: _t->add((*reinterpret_cast<std::add_pointer_t<char32_t>>(_a[1]))); break;
        case 4: _t->toClip(); break;
        case 5: _t->toClipUTF8(); break;
        case 6: _t->toClipHTML(); break;
        case 7: _t->fromClip(); break;
        case 8: _t->fromClipUTF8(); break;
        case 9: _t->flipText(); break;
        case 10: _t->setRtl((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->lineEditChanged(); break;
        default: ;
        }
    }
}

const QMetaObject *KCharSelectDia::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCharSelectDia::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KCharSelectDiaE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KCharSelectDia::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
